=======
Credits
=======

Development Lead
----------------

* Joel Akeret <jakeret@phys.ethz.ch>

Contributors
------------

None yet. Why not be the first?

Citations
---------

As you use **abcpmc** for your exciting discoveries, please cite the paper that describes the package: 

Akeret, J., Refregier, A., Amara, A, Seehars, S., and Hasner, C., JCAP (submitted 2015)
